@@ -47,11 +47,6 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->Snap->setValidator(new QRegExpValidator(regexer_snap, ui->Snap));
     ui->Opacity->setValidator(new QRegExpValidator(regexer_icon, ui->Opacity));
     progress3.setValue(80);
-    QImage png("/opt/theme-customizer/customizer.png");
-    QPixmap image;
-    image = image.fromImage(png);
-    ui->logo->setPixmap(image);
-    ui->logo->setGeometry(0,0,79,900);
     readgtkrc();
     progress3.setValue(100);
     progress3.cancel();
@@ -271,30 +266,14 @@ void MainWindow::processFinished(int)
 
     if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
 
-        QProcess *process2 = new QProcess(this);
-        process2->start("/usr/sbin/dsmetool -k /usr/bin/hildon-home");
+        system("dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Restarting services, your screen will blink! After all is done, rebooting the device is recommended to reload all new values' uint32:0 string:'OK'");
+        system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Restarting hildon-home...'");
+        system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home && sleep 2 && run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
+        system("sleep 2 && killall hildon-status-menu");
+        system("sleep 2 && killall systemui");
+        system("sleep 2 && killall hildon-desktop");
+        system("sleep 2 && killall theme-customizer");
 
-        sleep(3);
-
-        QProcess *process5 = new QProcess(this);
-        process5->start("/usr/sbin/dsmetool -t /usr/bin/hildon-home");
-
-        sleep(15);
-
-        QProcess *process4 = new QProcess(this);
-        process4->start("killall hildon-desktop");
-
-        sleep(10);
-
-        QProcess *process6 = new QProcess(this);
-        process6->start("killall hildon-status-menu");
-
-        sleep(10);
-
-        sleep(5);
-
-        QProcess *process7 = new QProcess(this);
-        process7->start("killall theme-customizer");
     }
 
     progress.cancel();
@@ -580,3 +559,14 @@ void MainWindow::on_font8_editingFinished()
     f8 = ui->font8->text();
     ui->fontbuttonpressed->setStyleSheet(COLOR_STYLE.arg(f8, variables.value("DefaultBackgroundColor"), f8));
 }
+
+void MainWindow::on_pushButton_2_clicked()
+{
+
+        newWin = new backgrounds(this);
+        newWin->setAttribute(Qt::WA_Maemo5StackedWindow);
+        newWin->setAttribute(Qt::WA_DeleteOnClose);
+
+        newWin->show();
+
+}
